@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class RouteServerPropagationState
-  {
-    NOT_SET,
-    pending,
-    available,
-    deleting
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class RouteServerPropagationState { NOT_SET, pending, available, deleting };
 
-namespace RouteServerPropagationStateMapper
-{
+namespace RouteServerPropagationStateMapper {
 AWS_EC2_API RouteServerPropagationState GetRouteServerPropagationStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForRouteServerPropagationState(RouteServerPropagationState value);
-} // namespace RouteServerPropagationStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace RouteServerPropagationStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
